'use strict';

var defaultTemplate = function (tpl, data) {
  if (!data) { return tpl }

  var re = /{(.*?)}/g;

  return tpl.replace(re, function (_, key) {
    var ret = data;

    for (var i = 0, list = key.split('.'); i < list.length; i += 1) {
      var prop = list[i];

      ret = ret ? ret[prop] : '';
    }

    return ret || ''
  })
};

var Vue;

var Inter = function Inter(ref) {
  var locale = ref.locale;
  var locales = ref.locales;
  var template = ref.template; if ( template === void 0 ) template = defaultTemplate;

  if (process.env.NODE_ENV === 'development' && !Vue) {
    throw new Error('You have to install `vue-inter` first: Vue.use(Inter)')
  }

  this.template = template;
  this.locales = locales;

  var silent = Vue.config.silent;
  Vue.config.silent = true;
  this.vm = new Vue({
    data: {
      $$locale: locale
    }
  });
  Vue.config.silent = silent;
};

var prototypeAccessors = { locale: {} };

Inter.install = function install (_Vue) {
  Vue = _Vue;
  Vue.mixin({
    beforeCreate: function beforeCreate() {
      this.$inter =
        this.$options.inter || (this.$parent && this.$parent.$options.inter);
      if (this.$inter) {
        this.$i = this.$inter.get.bind(this.$inter);
      }
    }
  });
};

prototypeAccessors.locale.get = function () {
  return this.vm._data.$$locale
};

Inter.prototype.get = function get (key) {
    var data = [], len = arguments.length - 1;
    while ( len-- > 0 ) data[ len ] = arguments[ len + 1 ];

  var localeData = this.locales[this.locale];
  if (process.env.NODE_ENV === 'development' && !localeData) {
    throw new Error(("[vue-inter] Locale \"" + (this.locale) + "\" was not found"))
  }
  var message = localeData[key];
  if (process.env.NODE_ENV === 'development' && !message) {
    throw new Error(("[vue-inter] No message under \"" + key + "\" was found"))
  }
  return (ref = this).template.apply(ref, [ message ].concat( data ))
    var ref;
};

Inter.prototype.setLocale = function setLocale (locale) {
  this.vm._data.$$locale = locale;
  return this
};

Object.defineProperties( Inter.prototype, prototypeAccessors );

module.exports = Inter;
